@@ -35,9 +35,9 @@ get_item_args(struct menu_state *ctx, size_t index)
 	item_fmt[4].value.s = ctx->items->ptr[index].url->ptr;
 	item_fmt[5].value.s = ctx->items->ptr[index].title->ptr;
 	item_fmt[6].value.s = ctx->items->ptr[index].title->len > 0 ? ctx->items->ptr[index].title->ptr : ctx->items->ptr[index].url->ptr;
-	item_fmt[7].value.s = ctx->items->ptr[index].feed[0]->link->ptr;
+	item_fmt[7].value.s = ctx->items->ptr[index].feed[0]->url->ptr;
 	item_fmt[8].value.s = ctx->items->ptr[index].feed[0]->name ? ctx->items->ptr[index].feed[0]->name->ptr : "";
-	item_fmt[9].value.s = ctx->items->ptr[index].feed[0]->name ? ctx->items->ptr[index].feed[0]->name->ptr : ctx->items->ptr[index].feed[0]->link->ptr;
+	item_fmt[9].value.s = ctx->items->ptr[index].feed[0]->name ? ctx->items->ptr[index].feed[0]->name->ptr : ctx->items->ptr[index].feed[0]->url->ptr;
 	return item_fmt;
 }
 
@@ -112,6 +112,18 @@ mark_item_important(struct menu_state *ctx, size_t view_sel, bool status)
 	}
 }
 
+static void
+toggle_item_read(struct menu_state *ctx, size_t view_sel)
+{
+	mark_item_read(ctx, view_sel, ctx->items->ptr[view_sel].is_unread);
+}
+
+static void
+toggle_item_important(struct menu_state *ctx, size_t view_sel)
+{
+	mark_item_important(ctx, view_sel, !ctx->items->ptr[view_sel].is_important);
+}
+
 static void
 mark_all_items_read(struct menu_state *ctx, bool status)
 {
@@ -145,10 +157,10 @@ struct menu_state *
 items_menu_loop(struct menu_state *m)
 {
 	m->enumerator   = &is_item_valid;
+	m->printer      = &list_menu_writer;
 	m->get_args     = &get_item_args;
 	m->paint_action = &paint_item;
 	m->unread_state = &is_item_unread;
-	m->write_action = &list_menu_writer;
 	m->entry_format = get_cfg_wstring(NULL, m->flags & MENU_IS_EXPLORE ? CFG_MENU_EXPLORE_ITEM_ENTRY_FORMAT : CFG_MENU_ITEM_ENTRY_FORMAT);
 	items_age += 1;
 	if (m->is_initialized == false) {
@@ -175,10 +187,12 @@ items_menu_loop(struct menu_state *m)
 		switch (cmd) {
 			case INPUT_MARK_READ:         mark_item_read(m, m->view_sel, true);                     break;
 			case INPUT_MARK_UNREAD:       mark_item_read(m, m->view_sel, false);                    break;
+			case INPUT_TOGGLE_READ:       toggle_item_read(m, m->view_sel);                         break;
 			case INPUT_MARK_READ_ALL:     mark_all_items_read(m, true);                             break;
 			case INPUT_MARK_UNREAD_ALL:   mark_all_items_read(m, false);                            break;
 			case INPUT_MARK_IMPORTANT:    mark_item_important(m, m->view_sel, true);                break;
 			case INPUT_MARK_UNIMPORTANT:  mark_item_important(m, m->view_sel, false);               break;
+			case INPUT_TOGGLE_IMPORTANT:  toggle_item_important(m, m->view_sel);                    break;
 			case INPUT_RELOAD:            queue_updates(m->items->ptr[m->view_sel].feed, 1);        break;
 			case INPUT_RELOAD_ALL:        queue_updates(m->feeds_original, m->feeds_count);         break;
 			case INPUT_COPY_TO_CLIPBOARD: copy_string_to_clipboard(m->items->ptr[m->view_sel].url); break;
