@@ -13,16 +13,16 @@
 #include "termbox2.h"
 
 #ifndef NEWSRAFT_VERSION
-#define NEWSRAFT_VERSION "0.31"
+#define NEWSRAFT_VERSION "0.32"
 #endif
 
 #define ISWHITESPACE(A) (((A)==' ')||((A)=='\n')||((A)=='\t')||((A)=='\v')||((A)=='\f')||((A)=='\r'))
 #define ISWHITESPACEEXCEPTNEWLINE(A) (((A)==' ')||((A)=='\t')||((A)=='\v')||((A)=='\f')||((A)=='\r'))
 #define ISWIDEWHITESPACE(A) (((A)==L' ')||((A)==L'\n')||((A)==L'\t')||((A)==L'\v')||((A)==L'\f')||((A)==L'\r'))
 #define ISDIGIT(A) (((A)=='0')||((A)=='1')||((A)=='2')||((A)=='3')||((A)=='4')||((A)=='5')||((A)=='6')||((A)=='7')||((A)=='8')||((A)=='9'))
-#define INFO(...) log_write("INFO", __VA_ARGS__)
-#define WARN(...) log_write("WARN", __VA_ARGS__)
-#define FAIL(...) log_write("FAIL", __VA_ARGS__)
+#define INFO(...) log_print("INFO", __VA_ARGS__)
+#define WARN(...) log_print("WARN", __VA_ARGS__)
+#define FAIL(...) log_print("FAIL", __VA_ARGS__)
 #define info_status(...) status_write(CFG_COLOR_STATUS_INFO, __VA_ARGS__)
 #define fail_status(...) status_write(CFG_COLOR_STATUS_FAIL, __VA_ARGS__)
 #define LENGTH(A) ((sizeof(A))/(sizeof(*A)))
@@ -111,13 +111,6 @@ enum {
 	TEXT_LINKS, // Special block type which has to be populated with links
 };
 
-// Unknown type must have 0 value!
-enum {
-	MEDIA_TYPE_UNKNOWN = 0,
-	MEDIA_TYPE_XML,
-	MEDIA_TYPE_JSON,
-};
-
 enum {
 	NEWSRAFT_THREAD_DOWNLOAD = 0, // Downloads the feed from the web
 	NEWSRAFT_THREAD_SHRUNNER = 1, // Reads the feed from the command
@@ -157,10 +150,11 @@ struct input_binding {
 };
 
 struct feed_entry {
+	struct string *url;  // feed URL specified by the user
 	struct string *name;
-	struct string *link;
+	struct string *link; // link to webpage related to this feed
 	int64_t unread_count;
-	int64_t update_date; // Date of last feed update attempt
+	int64_t update_date; // date of last feed update attempt
 	struct config_context *cfg;
 	struct input_binding *binds;
 	struct string *errors;
@@ -226,9 +220,9 @@ struct menu_state {
 	const struct wstring *entry_format;
 	const struct wstring *find_filter;
 	bool (*enumerator)(struct menu_state *ctx, size_t index); // Checks if index is valid
+	void (*printer)(size_t index, WINDOW *w);                 // Prints to list entry
 	const struct format_arg *(*get_args)(struct menu_state *ctx, size_t index);
 	struct config_color (*paint_action)(struct menu_state *ctx, size_t index);
-	void (*write_action)(size_t index, WINDOW *w);
 	bool (*unread_state)(struct menu_state *ctx, size_t index);
 	bool (*failed_state)(struct menu_state *ctx, size_t index);
 	struct menu_state *prev;
@@ -273,20 +267,20 @@ struct render_result {
 struct getfeed_item {
 	struct string *guid;
 	struct string *title;
-	struct string *url;
+	struct string *link;
 	struct string *content;
 	struct string *attachments;
 	struct string *persons;
 	struct string *extras;
 	int64_t publication_date; // Publication date in seconds since the Epoch (0 means unset).
 	int64_t update_date; // Update date in seconds since the Epoch (0 means unset).
-	bool guid_is_url;
+	bool guid_is_link;
 	struct getfeed_item *next;
 };
 
 struct getfeed_feed {
 	struct string *title;
-	struct string *url;
+	struct string *link;
 	struct string *content;
 	struct string *attachments;
 	struct string *persons;
@@ -307,7 +301,9 @@ struct feed_update_state {
 	struct curl_slist *download_headers;
 	long http_response_code;
 
-	int8_t media_type;
+	// This function processes pieces of feed coming to us during the download.
+	bool (*process_fn)(struct feed_update_state *, const char *, size_t, bool);
+
 	XML_Parser xml_parser;
 	struct getfeed_feed feed;
 	bool in_item;
@@ -574,7 +570,8 @@ void queue_examine(void);
 // To write to the log stream use macros INFO, WARN or FAIL.
 // See "log.c" file for implementation.
 bool log_init(const char *path);
-void log_write(const char *prefix, const char *format, ...);
+int log_vprint(const char *prefix, const char *format, va_list args);
+int log_print(const char *prefix, const char *format, ...);
 FILE *log_get_stream(void);
 void log_stop(int error_code);
 
@@ -608,7 +605,6 @@ bool convert_opml_to_feeds(void);
 bool convert_feeds_to_opml(void);
 
 // See "parse_json" directory for implementation.
-void setup_json_parser(struct feed_update_state *data);
 bool newsraft_json_parse(struct feed_update_state *data, const char *content, size_t content_size);
 
 // See "insert_feed" directory for implementation.
