@@ -1,5 +1,5 @@
 /* ANSI-C code produced by gperf version 3.1 */
-/* Command-line: gperf -I -t -F ,0,NULL,NULL  */
+/* Command-line: gperf -m 1000 -I -t -F ,0,NULL,NULL  */
 /* Computed positions: -k'1,8,$' */
 
 #if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
@@ -36,8 +36,8 @@ struct xml_element_handler;
 #define MIN_WORD_LENGTH 3
 #define MAX_WORD_LENGTH 48
 #define MIN_HASH_VALUE 3
-#define MAX_HASH_VALUE 115
-/* maximum key range = 113, duplicates = 0 */
+#define MAX_HASH_VALUE 91
+/* maximum key range = 89, duplicates = 0 */
 
 #ifdef __GNUC__
 __inline
@@ -51,32 +51,32 @@ hash (register const char *str, register size_t len)
 {
   static unsigned char asso_values[] =
     {
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116,   5, 116, 116,
-       30, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116,   0, 116,   0,
-       35,  15, 116,  50,  20,  15, 116,   0,   0,  15,
-        5,  15,   0, 116,  20,  25,   0, 116, 116,   0,
-      116,  40, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116, 116, 116, 116, 116,
-      116, 116, 116, 116, 116, 116
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92,  0, 92, 92,
+      15, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92,  0, 92, 17,
+      17,  6, 92,  0,  0,  0, 92, 37,  0,  0,
+      28,  0,  0, 92, 11, 16,  0, 92, 92,  0,
+      92, 25, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92, 92, 92, 92, 92,
+      92, 92, 92, 92, 92, 92
     };
   register unsigned int hval = len;
 
@@ -105,15 +105,10 @@ in_word_set (register const char *str, register size_t len)
     {
       {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
       {"ttl",                                              XML_UNKNOWN_POS,  NULL,                    &rss_ttl_end},
-      {"link",                                             XML_UNKNOWN_POS,  NULL,                    &rss_link_end},
+      {"item",                                             GENERIC_ITEM,     &generic_item_starter,   &generic_item_ender},
       {"",0,NULL,NULL}, {"",0,NULL,NULL},
-      {"channel",                                          GENERIC_FEED,     NULL,                    NULL},
-      {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
-      {"",0,NULL,NULL},
       {"Channel",                                          GENERIC_FEED,     NULL,                    NULL},
       {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
-      {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
-      {"",0,NULL,NULL},
       {"title",                                            XML_UNKNOWN_POS,  NULL,                    &generic_title_end},
       {"",0,NULL,NULL},
       {"pubDate",                                          XML_UNKNOWN_POS,  NULL,                    &rss_pubdate_end},
@@ -121,76 +116,66 @@ in_word_set (register const char *str, register size_t len)
       {"author",                                           XML_UNKNOWN_POS,  NULL,                    &rss_author_end},
       {"",0,NULL,NULL},
       {"lastBuildDate",                                    XML_UNKNOWN_POS,  NULL,                    &log_xml_element_content_end},
-      {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
+      {"generator",                                        XML_UNKNOWN_POS,  NULL,                    &log_xml_element_content_end},
+      {"guid",                                             XML_UNKNOWN_POS,  &rss_guid_start,         &generic_guid_end},
       {"",0,NULL,NULL}, {"",0,NULL,NULL},
-      {"item",                                             GENERIC_ITEM,     &generic_item_starter,   &generic_item_ender},
-      {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
-      {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
-      {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
+      {"channel",                                          GENERIC_FEED,     NULL,                    NULL},
+      {"managingEditor",                                   XML_UNKNOWN_POS,  NULL,                    &rss_managingeditor_end},
       {"webMaster",                                        XML_UNKNOWN_POS,  NULL,                    &log_xml_element_content_end},
-      {"",0,NULL,NULL},
-      {"source",                                           XML_UNKNOWN_POS,  &rss_source_start,       &rss_source_end},
       {"http://www.rbc.ru full-text",                      XML_UNKNOWN_POS,  NULL,                    &generic_plain_content_end},
-      {"",0,NULL,NULL},
-      {"http://purl.org/rss/1.0/ link",                    XML_UNKNOWN_POS,  NULL,                    &rss_link_end},
+      {"source",                                           XML_UNKNOWN_POS,  &rss_source_start,       &rss_source_end},
+      {"http://purl.org/rss/1.0/ item",                    GENERIC_ITEM,     &generic_item_starter,   &generic_item_ender},
       {"http://turbo.yandex.ru content",                   XML_UNKNOWN_POS,  NULL,                    &generic_html_content_end},
-      {"description",                                      XML_UNKNOWN_POS,  NULL,                    &generic_html_content_end},
-      {"http://www.w3.org/2005/Atom link",                 XML_UNKNOWN_POS,  &atom_link_start,        NULL},
+      {"http://www.w3.org/2005/Atom uri",                  XML_UNKNOWN_POS,  NULL,                    &uri_end},
+      {"enclosure",                                        XML_UNKNOWN_POS,  &rss_enclosure_start,    NULL},
       {"http://www.w3.org/2005/Atom email",                XML_UNKNOWN_POS,  NULL,                    &email_end},
       {"http://www.georss.org/georss point",               XML_UNKNOWN_POS,  NULL,                    &georss_point_end},
       {"http://www.w3.org/2005/Atom content",              XML_UNKNOWN_POS,  &atom_content_start,     &atom_content_end},
-      {"http://news.yandex.ru full-text",                  XML_UNKNOWN_POS,  NULL,                    &generic_html_content_end},
-      {"",0,NULL,NULL},
-      {"comments",                                         XML_UNKNOWN_POS,  NULL,                    &rss_comments_end},
-      {"enclosure",                                        XML_UNKNOWN_POS,  &rss_enclosure_start,    NULL},
-      {"http://purl.org/dc/elements/1.1/ subject",         XML_UNKNOWN_POS,  NULL,                    &generic_category_end},
-      {"http://purl.org/rss/1.0/ description",             XML_UNKNOWN_POS,  NULL,                    &generic_html_content_end},
-      {"",0,NULL,NULL}, {"",0,NULL,NULL},
-      {"http://purl.org/rss/1.0/ item",                    GENERIC_ITEM,     &generic_item_starter,   &generic_item_ender},
       {"http://purl.org/rss/1.0/ title",                   XML_UNKNOWN_POS,  NULL,                    &generic_title_end},
-      {"http://www.w3.org/2005/Atom uri",                  XML_UNKNOWN_POS,  NULL,                    &uri_end},
+      {"",0,NULL,NULL},
       {"http://www.w3.org/2005/Atom name",                 XML_UNKNOWN_POS,  NULL,                    &name_end},
       {"http://www.w3.org/2005/Atom title",                XML_UNKNOWN_POS,  NULL,                    &generic_title_end},
-      {"http://purl.org/dc/elements/1.1/ description",     XML_UNKNOWN_POS,  NULL,                    &generic_plain_content_end},
-      {"",0,NULL,NULL},
+      {"http://purl.org/dc/elements/1.1/ subject",         XML_UNKNOWN_POS,  NULL,                    &generic_category_end},
+      {"link",                                             XML_UNKNOWN_POS,  NULL,                    &rss_link_end},
       {"http://www.w3.org/2005/Atom subtitle",             XML_UNKNOWN_POS,  &atom_subtitle_start,    &atom_subtitle_end},
       {"http://purl.org/dc/elements/1.1/ date",            XML_UNKNOWN_POS,  NULL,                    &update_date_end},
       {"http://purl.org/dc/elements/1.1/ title",           XML_UNKNOWN_POS,  NULL,                    &dublincore_title_end},
       {"http://www.w3.org/2005/Atom author",               ATOM_AUTHOR,      &author_start,           NULL},
       {"http://www.opengis.net/gml pos",                   XML_UNKNOWN_POS,  NULL,                    &georss_point_end},
-      {"",0,NULL,NULL},
+      {"http://www.w3.org/2005/Atom id",                   XML_UNKNOWN_POS,  NULL,                    &generic_guid_end},
       {"http://www.w3.org/2005/Atom generator",            XML_UNKNOWN_POS,  &atom_generator_start,   &log_xml_element_content_end},
-      {"",0,NULL,NULL},
+      {"http://www.w3.org/2005/Atom feed",                 GENERIC_FEED,     NULL,                    NULL},
       {"http://www.w3.org/2005/Atom contributor",          ATOM_AUTHOR,      &contributor_start,      NULL},
       {"http://purl.org/dc/elements/1.1/ creator",         XML_UNKNOWN_POS,  NULL,                    &dublincore_creator_end},
-      {"",0,NULL,NULL},
-      {"http://search.yahoo.com/mrss/ content",            MEDIARSS_CONTENT, &mediarss_content_start, NULL},
-      {"http://search.yahoo.com/mrss/ peerLink",           XML_UNKNOWN_POS,  &peerlink_start,         NULL},
-      {"http://purl.org/dc/elements/1.1/ contributor",     XML_UNKNOWN_POS,  NULL,                    &dublincore_contributor_end},
-      {"http://www.w3.org/2005/Atom id",                   XML_UNKNOWN_POS,  NULL,                    &generic_guid_end},
-      {"",0,NULL,NULL},
-      {"http://www.w3.org/2005/Atom feed",                 GENERIC_FEED,     NULL,                    NULL},
-      {"category",                                         XML_UNKNOWN_POS,  NULL,                    &generic_category_end},
-      {"guid",                                             XML_UNKNOWN_POS,  &rss_guid_start,         &generic_guid_end},
       {"http://www.w3.org/2005/Atom updated",              XML_UNKNOWN_POS,  NULL,                    &update_date_end},
-      {"http://search.yahoo.com/mrss/ description",        XML_UNKNOWN_POS,  &description_start,      &description_end},
+      {"http://search.yahoo.com/mrss/ content",            MEDIARSS_CONTENT, &mediarss_content_start, NULL},
       {"http://www.w3.org/2005/Atom published",            XML_UNKNOWN_POS,  NULL,                    &published_end},
+      {"http://purl.org/dc/elements/1.1/ contributor",     XML_UNKNOWN_POS,  NULL,                    &dublincore_contributor_end},
+      {"description",                                      XML_UNKNOWN_POS,  NULL,                    &generic_html_content_end},
+      {"comments",                                         XML_UNKNOWN_POS,  NULL,                    &rss_comments_end},
       {"http://www.w3.org/2005/Atom entry",                GENERIC_ITEM,     &generic_item_starter,   &generic_item_ender},
-      {"generator",                                        XML_UNKNOWN_POS,  NULL,                    &log_xml_element_content_end},
+      {"http://news.yandex.ru full-text",                  XML_UNKNOWN_POS,  NULL,                    &generic_html_content_end},
       {"http://www.w3.org/2005/Atom summary",              XML_UNKNOWN_POS,  &atom_content_start,     &atom_content_end},
       {"http://www.w3.org/2005/Atom category",             XML_UNKNOWN_POS,  &atom_category_start,    NULL},
       {"http://www.w3.org/1999/02/22-rdf-syntax-ns# RDF",  GENERIC_FEED,     NULL,                    NULL},
-      {"",0,NULL,NULL},
-      {"managingEditor",                                   XML_UNKNOWN_POS,  NULL,                    &rss_managingeditor_end},
-      {"",0,NULL,NULL},
       {"http://search.yahoo.com/mrss/ player",             XML_UNKNOWN_POS,  &embed_or_player_start,  NULL},
-      {"",0,NULL,NULL},
+      {"http://purl.org/rss/1.0/ description",             XML_UNKNOWN_POS,  NULL,                    &generic_html_content_end},
       {"http://purl.org/rss/1.0/modules/content/ encoded", XML_UNKNOWN_POS,  NULL,                    &generic_html_content_end},
+      {"http://purl.org/rss/1.0/ link",                    XML_UNKNOWN_POS,  NULL,                    &rss_link_end},
+      {"",0,NULL,NULL},
+      {"http://search.yahoo.com/mrss/ embed",              XML_UNKNOWN_POS,  &embed_or_player_start,  NULL},
+      {"http://www.w3.org/2005/Atom link",                 XML_UNKNOWN_POS,  &atom_link_start,        NULL},
+      {"",0,NULL,NULL}, {"",0,NULL,NULL},
+      {"http://purl.org/dc/elements/1.1/ description",     XML_UNKNOWN_POS,  NULL,                    &generic_plain_content_end},
+      {"",0,NULL,NULL}, {"",0,NULL,NULL},
+      {"category",                                         XML_UNKNOWN_POS,  NULL,                    &generic_category_end},
       {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
       {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
       {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
+      {"http://search.yahoo.com/mrss/ description",        XML_UNKNOWN_POS,  &description_start,      &description_end},
+      {"",0,NULL,NULL}, {"",0,NULL,NULL}, {"",0,NULL,NULL},
       {"",0,NULL,NULL}, {"",0,NULL,NULL},
-      {"http://search.yahoo.com/mrss/ embed",              XML_UNKNOWN_POS,  &embed_or_player_start,  NULL}
+      {"http://search.yahoo.com/mrss/ peerLink",           XML_UNKNOWN_POS,  &peerlink_start,         NULL}
     };
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
