@@ -146,7 +146,7 @@ url_mark_handler(struct html_render *ctx, GumboVector *attrs)
 		line_string(ctx->line, L" "); // It's &nbsp;
 	}
 
-	line_style(ctx->line, A_BOLD);
+	line_style(ctx->line, TB_BOLD);
 
 	line_string(ctx->line, index);
 
@@ -525,104 +525,104 @@ free_html_table(struct html_table *table)
 }
 
 static const struct html_element_renderer renderers[] = {
-	{GUMBO_TAG_SPAN,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_P,          true,  2, 2, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_BR,         true,  0, 0, NULL, NULL, &br_handler,           NULL,                A_NORMAL},
-	{GUMBO_TAG_HR,         true,  1, 1, NULL, NULL, &hr_handler,           NULL,                A_NORMAL},
-	{GUMBO_TAG_A,          true,  0, 0, NULL, NULL, NULL,                  &url_mark_handler,   A_UNDERLINE},
-	{GUMBO_TAG_IMG,        true,  0, 0, NULL, L"[image]",  NULL,           &url_mark_handler,   A_UNDERLINE},
-	{GUMBO_TAG_IFRAME,     true,  0, 0, NULL, L"[iframe]", NULL,           &url_mark_handler,   A_UNDERLINE},
-	{GUMBO_TAG_EMBED,      true,  0, 0, NULL, L"[embed]",  NULL,           &url_mark_handler,   A_UNDERLINE},
-	{GUMBO_TAG_SOURCE,     true,  0, 0, NULL, L"[source]", NULL,           &url_mark_handler,   A_UNDERLINE},
-	{GUMBO_TAG_OBJECT,     true,  0, 0, NULL, L"[object]", NULL,           &url_mark_handler,   A_UNDERLINE},
-	{GUMBO_TAG_AUDIO,      true,  0, 0, NULL, L"[audio]",  NULL,           &url_mark_handler,   A_UNDERLINE},
-	{GUMBO_TAG_VIDEO,      true,  0, 0, NULL, L"[video]",  NULL,           &url_mark_handler,   A_UNDERLINE},
-	{GUMBO_TAG_U,          true,  0, 0, NULL, NULL, NULL,                  NULL,                A_UNDERLINE},
-	{GUMBO_TAG_B,          true,  0, 0, NULL, NULL, NULL,                  NULL,                A_BOLD},
-	{GUMBO_TAG_BIG,        true,  0, 0, NULL, NULL, NULL,                  NULL,                A_BOLD},
-	{GUMBO_TAG_I,          true,  0, 0, NULL, NULL, NULL,                  NULL,                NEWSRAFT_ITALIC},
-	{GUMBO_TAG_EM,         true,  0, 0, NULL, NULL, NULL,                  NULL,                NEWSRAFT_ITALIC},
-	{GUMBO_TAG_VAR,        true,  0, 0, NULL, NULL, NULL,                  NULL,                NEWSRAFT_ITALIC},
-	{GUMBO_TAG_SMALL,      true,  0, 0, NULL, NULL, NULL,                  NULL,                NEWSRAFT_ITALIC},
-	{GUMBO_TAG_DFN,        true,  0, 0, NULL, NULL, NULL,                  NULL,                NEWSRAFT_ITALIC},
-	{GUMBO_TAG_INS,        true,  0, 0, NULL, NULL, NULL,                  NULL,                NEWSRAFT_ITALIC},
-	{GUMBO_TAG_ADDRESS,    true,  1, 1, NULL, NULL, NULL,                  NULL,                NEWSRAFT_ITALIC},
-	{GUMBO_TAG_MARK,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_BOLD|NEWSRAFT_ITALIC},
-	{GUMBO_TAG_STRONG,     true,  0, 0, NULL, NULL, NULL,                  NULL,                A_BOLD},
-	{GUMBO_TAG_HEADER,     true,  3, 2, NULL, NULL, NULL,                  NULL,                A_BOLD},
-	{GUMBO_TAG_H1,         true,  3, 2, NULL, NULL, NULL,                  NULL,                A_BOLD},
-	{GUMBO_TAG_H2,         true,  3, 2, NULL, NULL, NULL,                  NULL,                A_BOLD},
-	{GUMBO_TAG_H3,         true,  3, 2, NULL, NULL, NULL,                  NULL,                A_BOLD},
-	{GUMBO_TAG_H4,         true,  3, 2, NULL, NULL, NULL,                  NULL,                A_BOLD},
-	{GUMBO_TAG_H5,         true,  3, 2, NULL, NULL, NULL,                  NULL,                A_BOLD},
-	{GUMBO_TAG_H6,         true,  3, 2, NULL, NULL, NULL,                  NULL,                A_BOLD},
-	{GUMBO_TAG_PRE,        true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_LI,         true,  1, 1, NULL, NULL, &li_handler,           NULL,                A_NORMAL},
-	{GUMBO_TAG_UL,         true,  0, 0, NULL, NULL, &ul_start_handler,     &ul_end_handler,     A_NORMAL},
-	{GUMBO_TAG_OL,         true,  0, 0, NULL, NULL, &ol_start_handler,     &ul_end_handler,     A_NORMAL},
-	{GUMBO_TAG_FIGURE,     true,  2, 2, NULL, NULL, &indent_start_handler, &indent_end_handler, A_NORMAL},
-	{GUMBO_TAG_BLOCKQUOTE, true,  2, 2, NULL, NULL, &indent_start_handler, &indent_end_handler, A_NORMAL},
-	{GUMBO_TAG_DD,         true,  1, 1, NULL, NULL, &indent_start_handler, &indent_end_handler, A_NORMAL},
-	{GUMBO_TAG_TD,         true,  0, 0, NULL, NULL, &html_table_add_cell,  NULL,                A_NORMAL},
-	{GUMBO_TAG_TH,         true,  0, 0, NULL, NULL, &html_table_add_cell,  NULL,                A_NORMAL},
-	{GUMBO_TAG_TR,         true,  0, 0, NULL, NULL, &html_table_add_row,   NULL,                A_NORMAL},
-	{GUMBO_TAG_ABBR,       true,  0, 0, NULL, NULL, NULL,                  &abbr_handler,       A_NORMAL},
-	{GUMBO_TAG_INPUT,      true,  0, 0, NULL, NULL, &input_handler,        NULL,                A_NORMAL},
-	{GUMBO_TAG_DIV,        true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_CENTER,     true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_MAIN,       true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_ARTICLE,    true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_SUMMARY,    true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_FIGCAPTION, true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_SECTION,    true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_FOOTER,     true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_OPTION,     true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_FORM,       true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_ASIDE,      true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_NAV,        true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_HGROUP,     true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_DT,         true,  1, 1, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_DL,         true,  2, 2, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_DETAILS,    true,  2, 2, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_LABEL,      true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_TEXTAREA,   true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_CODE,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_TT,         true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_SAMP,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_KBD,        true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_CITE,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_TIME,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_FONT,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_BASEFONT,   true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_THEAD,      true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_TBODY,      true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_TFOOT,      true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_WBR,        true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_NOSCRIPT,   true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_DATA,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_APPLET,     true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_PARAM,      true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_LINK,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_CANVAS,     true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_META,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_BODY,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_HTML,       true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_SUP,        true,  0, 0, L"^",  NULL, NULL,                 NULL,                A_NORMAL},
-	{GUMBO_TAG_Q,          true,  0, 0, L"\"", L"\"", NULL,                NULL,                A_NORMAL},
-	{GUMBO_TAG_BUTTON,     true,  0, 0, L"[",  L"]",  NULL,                NULL,                A_NORMAL},
-	{GUMBO_TAG_SVG,        false, 0, 0, NULL, L" [svg image]", NULL,       NULL,                A_NORMAL},
-	{GUMBO_TAG_HEAD,       false, 0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_STYLE,      false, 0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_SCRIPT,     false, 0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	// {GUMBO_TAG_PICTURE, true,  0, 0, NULL, NULL, NULL, /* not gumbo */  NULL,                A_NORMAL},
+	{GUMBO_TAG_SPAN,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_P,          true,  2, 2, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_BR,         true,  0, 0, NULL, NULL, &br_handler,           NULL,                TB_DEFAULT},
+	{GUMBO_TAG_HR,         true,  1, 1, NULL, NULL, &hr_handler,           NULL,                TB_DEFAULT},
+	{GUMBO_TAG_A,          true,  0, 0, NULL, NULL, NULL,                  &url_mark_handler,   TB_UNDERLINE},
+	{GUMBO_TAG_IMG,        true,  0, 0, NULL, L"[image]",  NULL,           &url_mark_handler,   TB_UNDERLINE},
+	{GUMBO_TAG_IFRAME,     true,  0, 0, NULL, L"[iframe]", NULL,           &url_mark_handler,   TB_UNDERLINE},
+	{GUMBO_TAG_EMBED,      true,  0, 0, NULL, L"[embed]",  NULL,           &url_mark_handler,   TB_UNDERLINE},
+	{GUMBO_TAG_SOURCE,     true,  0, 0, NULL, L"[source]", NULL,           &url_mark_handler,   TB_UNDERLINE},
+	{GUMBO_TAG_OBJECT,     true,  0, 0, NULL, L"[object]", NULL,           &url_mark_handler,   TB_UNDERLINE},
+	{GUMBO_TAG_AUDIO,      true,  0, 0, NULL, L"[audio]",  NULL,           &url_mark_handler,   TB_UNDERLINE},
+	{GUMBO_TAG_VIDEO,      true,  0, 0, NULL, L"[video]",  NULL,           &url_mark_handler,   TB_UNDERLINE},
+	{GUMBO_TAG_U,          true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_UNDERLINE},
+	{GUMBO_TAG_B,          true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_BOLD},
+	{GUMBO_TAG_BIG,        true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_BOLD},
+	{GUMBO_TAG_I,          true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_ITALIC},
+	{GUMBO_TAG_EM,         true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_ITALIC},
+	{GUMBO_TAG_VAR,        true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_ITALIC},
+	{GUMBO_TAG_SMALL,      true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_ITALIC},
+	{GUMBO_TAG_DFN,        true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_ITALIC},
+	{GUMBO_TAG_INS,        true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_ITALIC},
+	{GUMBO_TAG_ADDRESS,    true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_ITALIC},
+	{GUMBO_TAG_MARK,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_BOLD|TB_ITALIC},
+	{GUMBO_TAG_STRONG,     true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_BOLD},
+	{GUMBO_TAG_HEADER,     true,  3, 2, NULL, NULL, NULL,                  NULL,                TB_BOLD},
+	{GUMBO_TAG_H1,         true,  3, 2, NULL, NULL, NULL,                  NULL,                TB_BOLD},
+	{GUMBO_TAG_H2,         true,  3, 2, NULL, NULL, NULL,                  NULL,                TB_BOLD},
+	{GUMBO_TAG_H3,         true,  3, 2, NULL, NULL, NULL,                  NULL,                TB_BOLD},
+	{GUMBO_TAG_H4,         true,  3, 2, NULL, NULL, NULL,                  NULL,                TB_BOLD},
+	{GUMBO_TAG_H5,         true,  3, 2, NULL, NULL, NULL,                  NULL,                TB_BOLD},
+	{GUMBO_TAG_H6,         true,  3, 2, NULL, NULL, NULL,                  NULL,                TB_BOLD},
+	{GUMBO_TAG_PRE,        true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_LI,         true,  1, 1, NULL, NULL, &li_handler,           NULL,                TB_DEFAULT},
+	{GUMBO_TAG_UL,         true,  0, 0, NULL, NULL, &ul_start_handler,     &ul_end_handler,     TB_DEFAULT},
+	{GUMBO_TAG_OL,         true,  0, 0, NULL, NULL, &ol_start_handler,     &ul_end_handler,     TB_DEFAULT},
+	{GUMBO_TAG_FIGURE,     true,  2, 2, NULL, NULL, &indent_start_handler, &indent_end_handler, TB_DEFAULT},
+	{GUMBO_TAG_BLOCKQUOTE, true,  2, 2, NULL, NULL, &indent_start_handler, &indent_end_handler, TB_DEFAULT},
+	{GUMBO_TAG_DD,         true,  1, 1, NULL, NULL, &indent_start_handler, &indent_end_handler, TB_DEFAULT},
+	{GUMBO_TAG_TD,         true,  0, 0, NULL, NULL, &html_table_add_cell,  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_TH,         true,  0, 0, NULL, NULL, &html_table_add_cell,  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_TR,         true,  0, 0, NULL, NULL, &html_table_add_row,   NULL,                TB_DEFAULT},
+	{GUMBO_TAG_ABBR,       true,  0, 0, NULL, NULL, NULL,                  &abbr_handler,       TB_DEFAULT},
+	{GUMBO_TAG_INPUT,      true,  0, 0, NULL, NULL, &input_handler,        NULL,                TB_DEFAULT},
+	{GUMBO_TAG_DIV,        true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_CENTER,     true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_MAIN,       true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_ARTICLE,    true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_SUMMARY,    true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_FIGCAPTION, true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_SECTION,    true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_FOOTER,     true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_OPTION,     true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_FORM,       true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_ASIDE,      true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_NAV,        true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_HGROUP,     true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_DT,         true,  1, 1, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_DL,         true,  2, 2, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_DETAILS,    true,  2, 2, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_LABEL,      true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_TEXTAREA,   true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_CODE,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_TT,         true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_SAMP,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_KBD,        true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_CITE,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_TIME,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_FONT,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_BASEFONT,   true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_THEAD,      true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_TBODY,      true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_TFOOT,      true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_WBR,        true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_NOSCRIPT,   true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_DATA,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_APPLET,     true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_PARAM,      true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_LINK,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_CANVAS,     true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_META,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_BODY,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_HTML,       true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_SUP,        true,  0, 0, L"^",  NULL, NULL,                 NULL,                TB_DEFAULT},
+	{GUMBO_TAG_Q,          true,  0, 0, L"\"", L"\"", NULL,                NULL,                TB_DEFAULT},
+	{GUMBO_TAG_BUTTON,     true,  0, 0, L"[",  L"]",  NULL,                NULL,                TB_DEFAULT},
+	{GUMBO_TAG_SVG,        false, 0, 0, NULL, L" [svg image]", NULL,       NULL,                TB_DEFAULT},
+	{GUMBO_TAG_HEAD,       false, 0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_STYLE,      false, 0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_SCRIPT,     false, 0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	// {GUMBO_TAG_PICTURE, true,  0, 0, NULL, NULL, NULL, /* not gumbo */  NULL,                TB_DEFAULT},
 
 	// Gumbo can assign thead, tbody and tfoot tags to table element under
 	// some circumstances, so we need to ignore these to avoid tag display.
-	{GUMBO_TAG_THEAD,      true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_TBODY,      true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
-	{GUMBO_TAG_TFOOT,      true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
+	{GUMBO_TAG_THEAD,      true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_TBODY,      true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
+	{GUMBO_TAG_TFOOT,      true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
 
-	{GUMBO_TAG_UNKNOWN,    true,  0, 0, NULL, NULL, NULL,                  NULL,                A_NORMAL},
+	{GUMBO_TAG_UNKNOWN,    true,  0, 0, NULL, NULL, NULL,                  NULL,                TB_DEFAULT},
 };
 
 static void
@@ -686,7 +686,7 @@ render_html(GumboNode *node, struct html_render *ctx)
 			if (renderers[i].start_handler != NULL) {
 				renderers[i].start_handler(ctx, &node->v.element.attributes);
 			}
-			if (renderers[i].video_attrs != A_NORMAL) {
+			if (renderers[i].video_attrs != TB_DEFAULT) {
 				line_style(ctx->line, renderers[i].video_attrs);
 			}
 			line_string(ctx->line, renderers[i].prefix);
@@ -696,7 +696,7 @@ render_html(GumboNode *node, struct html_render *ctx)
 				}
 			}
 			line_string(ctx->line, renderers[i].suffix);
-			if (renderers[i].video_attrs != A_NORMAL) {
+			if (renderers[i].video_attrs != TB_DEFAULT) {
 				line_unstyle(ctx->line);
 			}
 			if (renderers[i].end_handler != NULL) {
