@@ -15,11 +15,21 @@ static struct feed_section **sections_view = NULL;
 static size_t sections_count = 0;
 static sorting_method_t sections_sort = SORT_BY_INITIAL_ASC;
 
+static size_t
+get_sections_view_len(void)
+{
+	if (get_cfg_bool(NULL, CFG_GLOBAL_SECTION_HIDE)) {
+		return sections_count - 1;
+	} else {
+		return sections_count;
+	}
+}
+
 static bool
 is_section_valid(struct menu_state *ctx, size_t index)
 {
 	(void)ctx;
-	return index < sections_count ? true : false;
+	return index < get_sections_view_len() ? true : false;
 }
 
 static const struct format_arg *
@@ -105,8 +115,14 @@ make_sure_section_exists(const struct string *section_name)
 	sections_count += 1;
 
 	// Have to update it every time because primary array is realloc'ed just above.
-	for (size_t i = 0; i < sections_count; ++i) {
-		sections_view[i] = &sections[i];
+	if (get_cfg_bool(NULL, CFG_GLOBAL_SECTION_HIDE)) {
+		for (size_t i = 1; i < sections_count; ++i) {
+			sections_view[i - 1] = &sections[i];
+		}
+	} else {
+		for (size_t i = 0; i < sections_count; ++i) {
+			sections_view[i] = &sections[i];
+		}
 	}
 
 	return sections_count - 1;
@@ -116,7 +132,7 @@ static inline struct feed_entry *
 find_feed_in_section(const struct string *link, const struct feed_section *section)
 {
 	for (size_t i = 0; i < section->feeds_count; ++i) {
-		if ((link->len == section->feeds[i]->link->len) && (strcmp(link->ptr, section->feeds[i]->link->ptr) == 0)) {
+		if ((link->len == section->feeds[i]->url->len) && (strcmp(link->ptr, section->feeds[i]->url->ptr) == 0)) {
 			return section->feeds[i];
 		}
 	}
@@ -126,17 +142,17 @@ find_feed_in_section(const struct string *link, const struct feed_section *secti
 static inline struct feed_entry *
 copy_feed_to_global_section(const struct feed_entry *feed)
 {
-	struct feed_entry *duplicate = find_feed_in_section(feed->link, &sections[0]);
+	struct feed_entry *duplicate = find_feed_in_section(feed->url, &sections[0]);
 	if (duplicate != NULL) {
 		return duplicate;
 	}
-	INFO("Adding to global section: %s", feed->link->ptr);
+	INFO("Adding to global section: %s", feed->url->ptr);
 	size_t feed_index = (sections[0].feeds_count)++;
 	sections[0].feeds = newsraft_realloc(sections[0].feeds, sizeof(struct feed_entry *) * sections[0].feeds_count);
 	sections[0].feeds[feed_index] = newsraft_calloc(1, sizeof(struct feed_entry));
 
 	if (STRING_IS_EMPTY(feed->name)) {
-		sections[0].feeds[feed_index]->name = db_get_string_from_feed_table(feed->link, "title", 5);
+		sections[0].feeds[feed_index]->name = db_get_string_from_feed_table(feed->url, "title", 5);
 	} else {
 		sections[0].feeds[feed_index]->name = crtss(feed->name);
 	}
@@ -144,10 +160,11 @@ copy_feed_to_global_section(const struct feed_entry *feed)
 		inlinefy_string(sections[0].feeds[feed_index]->name);
 	}
 
-	sections[0].feeds[feed_index]->link   = crtss(feed->link);
+	sections[0].feeds[feed_index]->url    = crtss(feed->url);
+	sections[0].feeds[feed_index]->link   = db_get_string_from_feed_table(feed->url, "link", 4);
 	sections[0].feeds[feed_index]->errors = crtes(1);
 
-	sections[0].feeds[feed_index]->update_date = db_get_date_from_feeds_table(feed->link, "update_date", 11);
+	sections[0].feeds[feed_index]->update_date = db_get_date_from_feeds_table(feed->url, "update_date", 11);
 	return sections[0].feeds[feed_index];
 }
 
@@ -163,7 +180,7 @@ copy_feed_to_section(const struct feed_entry *feed_data, int64_t section_index)
 
 	// User sections contain only pointers to feeds in the global section
 	struct feed_section *section = sections + section_index;
-	if (find_feed_in_section(feed->link, section) == NULL) {
+	if (find_feed_in_section(feed->url, section) == NULL) {
 		section->feeds = newsraft_realloc(section->feeds, sizeof(struct feed_entry *) * (section->feeds_count + 1));
 		section->feeds[section->feeds_count] = feed;
 		section->feeds_count += 1;
@@ -208,7 +225,7 @@ purge_abandoned_feeds(void)
 		return false;
 	}
 	for (size_t i = 0; i < sections[0].feeds_count; ++i) {
-		db_bind_string(res, i + 1, sections[0].feeds[i]->link);
+		db_bind_string(res, i + 1, sections[0].feeds[i]->url);
 	}
 	bool status = sqlite3_step(res) == SQLITE_DONE ? true : false;
 	sqlite3_finalize(res);
@@ -222,6 +239,7 @@ free_sections(void)
 	size_t i;
 	for (i = 0; i < sections[0].feeds_count; ++i) {
 		if (sections[0].feeds[i] != NULL) {
+			free_string(sections[0].feeds[i]->url);
 			free_string(sections[0].feeds[i]->name);
 			free_string(sections[0].feeds[i]->link);
 			free_string(sections[0].feeds[i]->errors);
@@ -236,6 +254,7 @@ free_sections(void)
 		free_string(sections[i].name);
 		newsraft_free(sections[i].feeds);
 	}
+	newsraft_free(sections_view);
 	newsraft_free(sections);
 }
 
@@ -311,9 +330,9 @@ sort_sections(sorting_method_t method, bool we_are_already_in_sections_menu)
 	pthread_mutex_lock(&interface_lock);
 	sections_sort = method;
 	switch (sections_sort & ~1) {
-		case SORT_BY_UNREAD_ASC:   qsort(sections_view, sections_count, sizeof(struct feed_section *), &compare_sections_unread);   break;
-		case SORT_BY_INITIAL_ASC:  qsort(sections_view, sections_count, sizeof(struct feed_section *), &compare_sections_initial);  break;
-		case SORT_BY_ALPHABET_ASC: qsort(sections_view, sections_count, sizeof(struct feed_section *), &compare_sections_alphabet); break;
+		case SORT_BY_UNREAD_ASC:   qsort(sections_view, get_sections_view_len(), sizeof(struct feed_section *), &compare_sections_unread);   break;
+		case SORT_BY_INITIAL_ASC:  qsort(sections_view, get_sections_view_len(), sizeof(struct feed_section *), &compare_sections_initial);  break;
+		case SORT_BY_ALPHABET_ASC: qsort(sections_view, get_sections_view_len(), sizeof(struct feed_section *), &compare_sections_alphabet); break;
 	}
 	pthread_mutex_unlock(&interface_lock);
 	if (we_are_already_in_sections_menu == true) {
@@ -326,11 +345,11 @@ struct menu_state *
 sections_menu_loop(struct menu_state *m)
 {
 	m->enumerator   = &is_section_valid;
+	m->printer      = &list_menu_writer;
 	m->get_args     = &get_section_args;
 	m->paint_action = &paint_section;
 	m->unread_state = &is_section_unread;
 	m->failed_state = &is_section_failed;
-	m->write_action = &list_menu_writer;
 	m->entry_format = get_cfg_wstring(NULL, CFG_MENU_SECTION_ENTRY_FORMAT);
 	if (!(m->flags & MENU_DISABLE_SETTINGS)) {
 		// Don't set the menu names here because it's redundant!
